@@ -71,7 +71,7 @@ def start():
     sys.exit(1)
 
 
-def stop():
+def stop(exit=True):
     '''
     stops onion routing
     '''
@@ -84,16 +84,21 @@ def stop():
             "Tractor stopped",
             term.Attr.BOLD,
             term.Color.YELLOW))
+        if exit:
+            sys.exit(0)
+    print(term.format(
+        "Tractor seems to be stopped.",
+        term.Attr.BOLD,
+        term.Color.YELLOW))
+    if exit:
         sys.exit(0)
-    print("Tractor seems to be stopped.")
-    sys.exit(0)
 
 
 def restart():
     '''
     stop, then start
     '''
-    stop()
+    stop(exit=False)
     start()
 
 
@@ -110,7 +115,10 @@ def new_id():
             term.Attr.BOLD,
             term.Color.BLUE))
         sys.exit(0)
-    print("Tractor is stopped.")
+    print(term.format(
+        "Tractor is stopped.",
+        term.Attr.BOLD,
+        term.Color.YELLOW))
     sys.exit(1)
 
 
